/*
 * input.h
 *
 *  Created on: 2021年12月4日
 *      Author: pengzc
 */

#ifndef JNI_INPUT_H_
#define JNI_INPUT_H_
#include <string>
#include <list>
#include <linux/input.h>

#define CHECK_FAILURE(expression) \
  if ((expression) != 0) { \
    return -1; \
  }

struct Point {
  int x;
  int y;
};
/**
 * example:
 *     123,456
 * @param point
 * @return
 */
Point from_point_string(const std::string& point);

std::string to_event_string(const struct input_event& e);
struct input_event from_event_string(const std::string& str);

class Input {
public:
  Input(const std::string& dev);
  virtual ~Input();

  int Tap(const std::list<Point>& points, int interval);
  int Tap(int x, int y);
  int Swipe(int x1, int y1, int x2, int y2);

  /**
   *
   * @param buf
   * @param timeout_ms
   * @return 1 get event
   *         0 timeout
   *        <0 failure
   */
  int Wait(struct input_event* buf, int timeout_ms);

  int Inject(const struct input_event& e);

  const static int kMoveDelayTime = 1;//ms
  const static int kPressureTime = 100;//ms

private:
  std::string dev_;
  int fd_;
};

#endif /* JNI_INPUT_H_ */
